<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package nesiapress
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class('antialiased'); ?>>
<?php wp_body_open(); ?>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#primary"><?php esc_html_e( 'Skip to content', 'nesiapress' ); ?></a>

	<header id="masthead" class="site-header">
      <div class="np-header-container">
         <div class="header-inner">
            <div class="site-branding">
               <?php
               the_custom_logo();
               if ( is_front_page() && is_home() ) :
                  ?>
                  <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
                  <?php
               else :
                  ?>
                  <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
                  <?php
               endif;
               $nesiapress_description = get_bloginfo( 'description', 'display' );
               if ( $nesiapress_description || is_customize_preview() ) :
                  ?>
                  <p class="site-description"><?php echo $nesiapress_description; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></p>
               <?php endif; ?>
            </div><!-- .site-branding -->

            <div class="menu-button-wrapper">
               <button id="menu-toggle" class="menu-toggle">
                  <svg viewBox="0 0 20 20" class="toggle-icon" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
                     <g  stroke="none" stroke-width="1" fill="currentColor" fill-rule="evenodd">
                        <g id="icon-shape">
                           <path d="M0,3 L20,3 L20,5 L0,5 L0,3 Z M0,9 L20,9 L20,11 L0,11 L0,9 Z M0,15 L20,15 L20,17 L0,17 L0,15 Z" id="Combined-Shape"></path>
                        </g>
                     </g>
                  </svg><!-- .toggle-icon -->	
                  <?php _e( 'Menu', 'nesiapress' ); ?>
               </button> <!-- .menu-toggle -->
            </div> <!-- .menu-button-wrapper -->

            <div id="site-menu-inner" class="site-menu-inner">
               <nav id="site-navigation" class="main-navigation" role="navigation" aria-label="<?php esc_attr_e( 'Primary Menu', 'nesiapress' ); ?>">
                  <?php
                     wp_nav_menu(
                        array(
                           'theme_location' => 'primary',
                           'menu_class' 	  => 'primary-menu',
                        )
                     );
                  ?>
               </nav><!-- .main-navigation -->
            </div><!-- .site-menu-inner -->

         </div><!-- .header-inner -->
      </div><!-- .header-wrapper -->
   </header><!-- #site-header -->
